@@ -20,4 +20,5 @@ import LbAPCommon
 def test_parse_example1():
     with open(join(splitext(__file__)[0], "example1.yaml"), "rt") as fp:
         data = fp.read()
-    assert len(LbAPCommon.parse_yaml(data)) == 168
+    jobs_data, checks_data = LbAPCommon.parse_yaml(data)
+    assert len(jobs_data) == 168
